#
# Copyright 2010, Red Hat, Inc.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
#
# Author: Chris Lumens <clumens@redhat.com>

import autoqa.koji_utils
from autotest_lib.client.bin import test, utils
from autotest_lib.client.bin.test_config import config_loader
from autotest_lib.client.common_lib import error
from autoqa.test import AutoQATest
from autoqa.repoinfo import repoinfo
from autoqa.decorators import ExceptionCatcher
import logging
import os
import sys

class anaconda_storage(AutoQATest):
    version = 1

    @ExceptionCatcher()
    def setup(self, **kwargs):
        # Install packages that provide commands used by runtest.py
        cmd = "yum -y install livecd-tools qemu-kvm genisoimage parted " \
              "dosfstools qemu-img pyparted"
        utils.system(cmd)

    def process_exception(self, exc):
        self.framework.stopReportServer()
        AutoQATest.process_exception(self, exc)

    @ExceptionCatcher()
    def run_once(self, *args, **kwargs):
        # We need to get the directory containing framework/ into the
        # PYTHONPATH for the next import to work.
        sys.path.append(self.bindir)
        from framework import StorageTestFramework

        # I'm a pessimist, assume the blurst
        self.result = "FAILED"

        # Build arguments for the test script (runtest.py)
        repos = []
        if kwargs.get("hook","") == "post-koji-build":
            nvr = kwargs.get('nvr','')
            kojitag = kwargs.get('kojitag','')
            name = kwargs.get('name','')
            assert nvr.startswith("anaconda"), "This test is only applies to anaconda (not '%s')" % nvr

            # Add requested repo
            repo = repoinfo.getrepo_by_tag(kojitag)
            assert repo, "Unable to find repository configuration for tag '%s'" % kojitag
            repos.append(repo['url'])
            # Add applicable parent repos
            for repo in repo.get('parents',[]):
                repos.append(repo['url'])

        elif kwargs.get("hook","") == "post-tree-compose":
            repos = [kwargs.get("baseurl")]
        else:
            raise error.TestFail("Unsupported hook: %s" % kwargs.get("hook",""))

        logging.basicConfig(level=logging.DEBUG)

        self.framework = StorageTestFramework(livecddir=self.tmpdir,
                                              tmpdir=self.tmpdir,
                                              basedir=self.bindir+"/framework",
                                              resultsdir=self.resultsdir,
                                              repos=repos)
        self.framework.setupDirs()
        self.framework.startReportServer()
        self.framework.run()
        self.framework.stopReportServer()

        # check command return code
        if os.path.exists("%s/PASSED" % self.resultsdir):
            self.result = "PASSED"
